[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4730988.svg)](https://doi.org/10.5281/zenodo.4730988)


# Barrier3D
A spatially explicit exploratory model of coastal barrier evolution.

### Full documentation for Barrier3D is available at: <https://unc-cecl.github.io/Barrier3D/>

There are two primary branches for this repository:
- `Barrier3D-v1.0` -- Created by Ian Reeves and used for all simulations in Reeves et al., 2021 (GRL)
- `master` -- Contains a basical model interface, written by Eric Hutton and Katherine Anarde and used in Anarde et al., (in prep). This branch contains an abbreviated copy of `Barrier3D-v1.0` for testing purposes.
